@@ -9,14 +9,17 @@ class CreationDateAdminFieldsetMixin(AdminFieldsetMixin):
         }
     
     def get_readonly_fields(self, **_):
-        return ["created_at"]
+        return "created_at"
     
 
 class EditCreationDateAdminFieldsetMixin(AdminFieldsetMixin):
     def get_mixin_fields(self, **kwargs):
         data = super().get_mixin_fields(**kwargs)
         own_data = {
-            "default": "edited_at"
+            "created": "edited_at"
         }
         
         return common.combine_fields(data, own_data)
+    
+    def get_readonly_fields(self, **_):
+        return "edited_at"
